// 2021 Joe Gorse (c)
// 

#include "Application.h"
#include "../Generated/Resource.h"
#include "../Generated/ID_SCREEN_00.h"

#define DEBUG
#ifdef DEBUG
#include <Windows.h>
#include <debugapi.h>
#include <stdio.h>

char dbuffer[1024];
#define LE                "\n" // Unix/mac/wsl "\n"; Windows "\r\n"
#pragma warning( push )
#pragma warning( disable : 4101)
#define dlog(fmt, ...) \
    do { \
        sprintf(dbuffer, "%08d jhg: %d:%s(): " fmt LE, \
             GetTickCount(), __LINE__, __func__, __VA_ARGS__); \
        OutputDebugString(dbuffer); \
    } while (0)
#pragma warning( pop ) 
#endif

#define ID_WINDOW_00_EDIT (GUI_ID_USER + 20)
#define ID_BUTTON_00_01   (GUI_ID_USER + 21)
#define ID_BUTTON_00_02   (GUI_ID_USER + 22)
#define MSG_ANIM          (WM_USER     + 0x01)
#define MSG_ANIM_FADE_IN  (WM_USER     + 0x02)
#define MSG_ANIM_FADE_OUT (WM_USER     + 0x03)

static const GUI_WIDGET_CREATE_INFO _aDialogEdit[] = {
  { WINDOW_CreateIndirect, "Window", ID_WINDOW_00_EDIT, 1,     1, 318, 97, 0, 0x3 | WM_CF_MEMDEV, 0 },
  { BUTTON_CreateIndirect, "1", ID_BUTTON_00_01,       71,     27, 41, 41, 0, 0x3 | WM_CF_MEMDEV, 0 },
  { BUTTON_CreateIndirect, "2 exit", ID_BUTTON_00_02, 71+41+5, 27, 41, 41, 0, 0x3 | WM_CF_MEMDEV, 0 },
};

static WM_HWIN hScreen00;
static WM_HWIN hWindows[5];
static WM_HWIN hWindowsEdit[4];
static WM_HWIN hButtons[4];
static WM_HWIN hButtonsEdit[4];

static int row_focused  = 0; // index starts at 1. 0 is no selection.
static int row_selected = 0;

static const int row_y_unselected = 46;
static const int row_y_selected   = 98;

static void _AnimShiftRows(GUI_ANIM_INFO* pInfo, void* pVoid);

// Custom struct with data necessary for the animation
static struct ANIM_SEL_DATA {
    WM_HWIN hWin;
    int     yPosStart;
    int     yPosStop;
} aSelData;

GUI_ANIM_HANDLE hAnimSel;

static void update_row_selected(void) {
    if (row_focused > 4) row_focused = 0;
    if (row_focused < 0) row_focused = 4;
    for (int i=0;i<4+1;i++) // 5th is one offpage selection above 'r'
    	BUTTON_SetPressed(hButtons[i], (i == row_focused - 1 ? 1 : 0));
}

static void _OnDeleteSel(void* pVoid) {
    struct ANIM_SEL_DATA* pData;
    WM_MESSAGE msg;

    //
    // Get custom void pointer
    //
    pData = (struct ANIM_SEL_DATA*)pVoid;
    //
    // Do something after the animation has ended...
    //
    // TODO: Switch Screens here OR Transition state to draw those buttons for the digits to edit our row
    // Start button animation here

    if (aSelData.yPosStop == row_y_selected) {
        aSelData.yPosStart = row_y_selected;
        aSelData.yPosStop = row_y_unselected;
        dlog("selected, stage unselect for next shiftrow animation");

        //GUI_MEMDEV_FadeInWindow(hButtonsEdit[0], 500); // TODO: row_selected/focused index. TODO: the pattern of button layout per selected row.
        msg.hWin = hScreen00;           // Window to receive the message
        msg.hWinSrc = WM_HBKWIN;        // Source window sending the message
        //msg.MsgId = MSG_ANIM;           // Message ID
        msg.MsgId = MSG_ANIM_FADE_IN; // Message ID
        msg.Data.v = GUI_GetTime();     // Custom data value
        WM_SendMessage(hScreen00, &msg);
    }
    else if (aSelData.yPosStop == row_y_unselected)
    {
        aSelData.yPosStart = row_y_unselected;
        aSelData.yPosStop = row_y_selected;
        dlog("unselected, stage select for next shiftrow animation");
    }

    dlog("aSelData.yPosStart %d aSelData.yPosStop %d", aSelData.yPosStart, aSelData.yPosStop);
}

static void _AnimShiftRows(GUI_ANIM_INFO* pInfo, void* pVoid) {
    struct ANIM_SEL_DATA* pData;
    int ysize;
    static int last_ysize = 0;
    int dy = 0;

    pData = (struct ANIM_SEL_DATA*)pVoid;

    ysize = pData->yPosStart + ((pData->yPosStop - pData->yPosStart) * pInfo->Pos) / GUI_ANIM_RANGE;
    if (last_ysize != 0)
        dy = ysize - last_ysize;

    //dlog("ysize %d WM_GetYSize %d dy %d", ysize, WM_GetYSize(hWindows[row_focused - 1]), dy);

    if ((row_focused > 0) && (row_focused < 5)) {
        //dlog("hWindows ysize %d hButtons ysize %d", WM_GetYSize(hWindows[row_selected - 1]), WM_GetYSize(hButtons[row_selected - 1]));
        WM_SetYSize(hWindows[row_focused - 1], ysize);
        WM_SetYSize(hButtons[row_focused - 1], ysize);
        for (int i = row_focused; i < 5; i++) {
            //dlog("i %d WM_GetWinOrgY %d dy %d setval %d", i, WM_GetWinOrgY(hWindows[i]), dy, WM_GetWinOrgY(hWindows[i]) + dy);
            WM_MoveTo(hWindows[i], WM_GetWinOrgX(hWindows[i]), WM_GetWinOrgY(hWindows[i]) + dy);
        }
    }

    last_ysize = ysize;
}

static void MainMenuEdit_GUI_KEY_cbHook(const GUI_KEY_STATE* pState) {
    I32 v;
    WM_MESSAGE msg;

    if (pState) {
        switch (pState->Key) {
        case GUI_KEY_UP:
            if (pState->Pressed == 0) {
                // TODO: digit[col_focused ++]
            }
            break;
        case GUI_KEY_DOWN:
            if (pState->Pressed == 0) {
                // TODO: digit[col_focused --]
            }
            break;
        case GUI_KEY_LEFT:
            if (pState->Pressed == 0) {
                dlog("edit GUI_KEY_LEFT");
                // edit_col_focused --
                WM_SetFocus(hButtonsEdit[1]);
            }
            break;
        case GUI_KEY_RIGHT:
            if (pState->Pressed == 0) {
                dlog("edit GUI_KEY_RIGHT");
                // edit_col_focused --
                WM_SetFocus(hButtonsEdit[2]);
            }
            break;
        case GUI_KEY_ENTER:
            if (pState->Pressed == 0) {
                // destination for animation, then switch screen
                if (WM_HasFocus(hButtonsEdit[2])) {
                    dlog("edit hButtonsEdit[2] pressed");
                    //GUI_MEMDEV_FadeOutWindow(hWindowsEdit[0], 500); // TODO: row_selected/focused index. TODO: the pattern of button layout per selected row.

                    msg.hWin = hWindows[0];                                           // Window to receive the message
                    msg.hWinSrc = hButtons[row_focused > 0 ? row_focused - 1 : 0];    // Source window sending the message
                    msg.MsgId = MSG_ANIM_FADE_OUT;                                    // Message ID
                    msg.Data.v = GUI_GetTime();                                       // Custom data value
                    WM_SendMessage(hScreen00, &msg);

                    dlog("WM_SendMessage(hScreen00 %d, msg.MsgId %d msg.Data.v %d)", hScreen00, msg.MsgId, msg.Data.v);

                    //WM_DeleteWindow(hWindowsEdit[0]);
                }
            }
            break;
        }
    }
}

static void MainMenu_GUI_KEY_cbHook(const GUI_KEY_STATE* pState) {
    I32 v;
    WM_MESSAGE msg;

    if (pState) {
        switch (pState->Key) {
        case GUI_KEY_UP:
            if (pState->Pressed == 0) {
                row_focused--;
                update_row_selected();
            }
            break;
        case GUI_KEY_DOWN:
            if (pState->Pressed == 0) {
                row_focused++;
                update_row_selected();
            }
            break;
        case GUI_KEY_LEFT:
            if (pState->Pressed == 0) {
                v = APPW_GetVarData(ID_VAR_01, NULL);
                APPW_SetVarData(ID_VAR_01, ++v);
            }
            break;
        case GUI_KEY_RIGHT:
            if (pState->Pressed == 0) {
                v = APPW_GetVarData(ID_VAR_00, NULL);
                APPW_SetVarData(ID_VAR_00, ++v);
            }
            break;
        case GUI_KEY_ENTER:
            if (pState->Pressed == 0) {
                // destination for animation, then fade in the edit buttons
                if ((row_focused > 0) && (row_focused < 5)) {
                    //GUI_MEMDEV_FadeOutWindow(hButtonsEdit[0], 500); // TODO: row_selected/focused index. TODO: the pattern of button layout per selected row.

                    msg.hWin = hWindows[0];                                           // Window to receive the message
                    msg.hWinSrc = hButtons[row_focused > 0 ? row_focused - 1 : 0];    // Source window sending the message
                    msg.MsgId = MSG_ANIM;                                             // Message ID
                    msg.Data.v = GUI_GetTime();                                       // Custom data value
                    WM_SendMessage(hScreen00, &msg);

                    // NB: This is an example for how to trigger the ID_BUTTON_00 CLICKED case in cbID_SCREEN_00_Handler().
                    // NB: It may be useful if you need to do something specific based on the row at this point in the state transition.
                    //msg.hWin = hWindows[0];                                        // Window to receive the message
                    //msg.hWinSrc = hButtons[row_focused > 0 ? row_focused - 1 : 0]; // Source window sending the message
                    //msg.MsgId = WM_NOTIFY_PARENT;                                  // Message ID
                    //msg.Data.v = WM_NOTIFICATION_CLICKED;                          // Custom data value
                    //WM_SendMessage(hScreen00, &msg);
                    dlog("WM_SendMessage(hScreen00 %d, msg.MsgId %d msg.Data.v %d)", hScreen00, msg.MsgId, msg.Data.v);
                }
            }
            break;
        }
    }
}

// Callback for the edit mode window
void _cbDialogEdit(WM_MESSAGE* pMsg) {
    int Id;
    int NCode;

    switch (pMsg->MsgId) {
    case WM_INIT_DIALOG:
        dlog("WM_INIT_DIALOG");
        GUI_KEY__SetHook(MainMenuEdit_GUI_KEY_cbHook);

        //BUTTON_SetFont(hButtonsEdit[0], acArial_24_Normal_EXT_AA4);     // TODO: how to set this font from appwizard
        hButtonsEdit[1] = WM_GetDialogItem(pMsg->hWin, ID_BUTTON_00_01);  // TODO: add more buttons
        hButtonsEdit[2] = WM_GetDialogItem(pMsg->hWin, ID_BUTTON_00_02);

        break;
    //case MSG_ANIM_FADE_IN:
    //     break;
    //case MSG_ANIM:
    //    break;
    //case WM_PAINT:
    //    break;
    case WM_NOTIFY_PARENT:
        Id = WM_GetId(pMsg->hWinSrc);
        NCode = pMsg->Data.v;
        switch (Id) {
        case ID_BUTTON_00_01:
            switch (NCode) {
            case WM_NOTIFICATION_CLICKED:
                dlog("ID_BUTTON_00_01 CLICKED");
                break;
            case WM_NOTIFICATION_RELEASED:
                break;
            }
            break;
        case ID_BUTTON_00_02:
            switch (NCode) {
            case WM_NOTIFICATION_CLICKED:
                dlog("ID_BUTTON_00_02 CLICKED");
                GUI_MEMDEV_FadeOutWindow(pMsg->hWin, 500);
                break;
            case WM_NOTIFICATION_RELEASED:
                //GUI_MEMDEV_FadeOutWindow(hWindowsEdit[0], 500); // TODO: row_selected/focused index. TODO: the pattern of button layout per selected row.
                // TODO: msg to main for animation back
                break;
            }
            break;
        }
        break;
    case WM_PAINT:
        GUI_SetBkColor(GUI_MAKE_COLOR(0xffba6f01)); //(GUI_DARKBLUE);  // (GUI_MAKE_COLOR(0x88016fba)); // TODO: note working correctly
        GUI_Clear();
        break;
    default:
        WM_DefaultProc(pMsg);
        break;
    }
}

// callback for the main screen with 4 rows to select for editing
void cbID_SCREEN_00_Handler(WM_MESSAGE* pMsg) {
	int Id;
	int NCode;
    WM_MESSAGE msg;

    if (pMsg->MsgId == WM_NOTIFY_PARENT)
        dlog("MsgId WM_NOTIFY_PARENT %d hWin %d hWinSrc %d Id %d Data.v %d", pMsg->MsgId, pMsg->hWin, pMsg->hWinSrc, WM_GetId(pMsg->hWinSrc), pMsg->Data.v);
    //else
    //    dlog("MsgId %d hWin %d hWinSrc %d Data.v %d", pMsg->MsgId, pMsg->hWin, pMsg->hWinSrc, pMsg->Data.v);

	switch (pMsg->MsgId) {
	case WM_INIT_DIALOG:
        dlog("WM_INIT_DIALOG");

        hScreen00 = pMsg->hWin;

        hWindows[0] = WM_GetDialogItem(pMsg->hWin, ID_WINDOW_00);
        hWindows[1] = WM_GetDialogItem(pMsg->hWin, ID_WINDOW_01);
        hWindows[2] = WM_GetDialogItem(pMsg->hWin, ID_WINDOW_02);
        hWindows[3] = WM_GetDialogItem(pMsg->hWin, ID_WINDOW_03);
        hWindows[4] = WM_GetDialogItem(pMsg->hWin, ID_WINDOW_04);

        hButtons[0] = WM_GetDialogItem(pMsg->hWin, ID_BUTTON_00);
        hButtons[1] = WM_GetDialogItem(pMsg->hWin, ID_BUTTON_01);
        hButtons[2] = WM_GetDialogItem(pMsg->hWin, ID_BUTTON_02);
        hButtons[3] = WM_GetDialogItem(pMsg->hWin, ID_BUTTON_03);

		GUI_KEY__SetHook(MainMenu_GUI_KEY_cbHook);

        BUTTON_SetText(hButtonsEdit[0], "1");

		BUTTON_SetText(hButtons[0], "row 0 0.00");
		BUTTON_SetText(hButtons[1], "row 1 0.00");
        BUTTON_SetText(hButtons[2], "row 2 0.00");
        BUTTON_SetText(hButtons[3], "row 3 0.00");

        update_row_selected();

        aSelData.hWin = pMsg->hWin;
        aSelData.yPosStart = row_y_unselected;
        aSelData.yPosStop = row_y_selected;

		break;
    case MSG_ANIM_FADE_OUT:
        if (WM_IsWindow(hWindowsEdit[0]) != 0) {
            GUI_MEMDEV_FadeOutWindow(hWindowsEdit[0], 500); // TODO: row_selected/focused index. TODO: the pattern of button layout per selected row.
            WM_DeleteWindow(hWindowsEdit[0]);
        }
        GUI_KEY__SetHook(MainMenu_GUI_KEY_cbHook);

        msg.hWin = hWindows[0];                                           // Window to receive the message
        msg.hWinSrc = hButtons[row_focused > 0 ? row_focused - 1 : 0];    // Source window sending the message
        msg.MsgId = MSG_ANIM;                                             // Message ID
        msg.Data.v = GUI_GetTime();                                       // Custom data value
        WM_SendMessage(hScreen00, &msg);

        break;
    case MSG_ANIM_FADE_IN:
        if (WM_IsWindow(hWindowsEdit[0]) == 0) {
            hWindowsEdit[0] = GUI_CreateDialogBox(_aDialogEdit, GUI_COUNTOF(_aDialogEdit), _cbDialogEdit, pMsg->hWin, 1, 1); // WM_HBKWIN
        }
        GUI_MEMDEV_FadeInWindow(hWindowsEdit[0], 500); // TODO: row_selected/focused index. TODO: the pattern of button layout per selected row.
        break;
    case MSG_ANIM:
        hAnimSel = GUI_ANIM_Create(1000, 10, &aSelData, NULL); 
        GUI_ANIM_AddItem(hAnimSel, 0, 1000, ANIM_ACCELDECEL, &aSelData, _AnimShiftRows);
        GUI_ANIM_StartEx(hAnimSel, 1, _OnDeleteSel);
        break;
    case WM_PAINT:
        break;
    case WM_NOTIFY_PARENT:
		Id = WM_GetId(pMsg->hWinSrc);
		NCode = pMsg->Data.v;
		switch (Id) {
		case ID_BUTTON_00:
			switch (NCode) {
			case WM_NOTIFICATION_CLICKED:
				dlog("hello world! GUI_ALLOC_GetNumFreeBytes() %d GUI_ALLOC_GetNumUsedBytes() %d", GUI_ALLOC_GetNumFreeBytes(), GUI_ALLOC_GetNumUsedBytes());
				break;
			case WM_NOTIFICATION_RELEASED:
				break;
			}
		}
	}
}
